@@ -41,7 +41,7 @@
 #include <QElapsedTimer>
 
 Q_DECLARE_METATYPE(QSet<qint64>)
-Q_DECLARE_METATYPE(QList<qint64>)
+Q_DECLARE_METATYPE(QVector<qint64>)
 
 class SearchPluginTest : public QObject
 {
@@ -56,7 +56,7 @@ private:
     void resultSearch()
     {
         QFETCH(QString, query);
-        QFETCH(QList<qint64>, collections);
+        QFETCH(QVector<qint64>, collections);
         QFETCH(QStringList, mimeTypes);
         QFETCH(QSet<qint64>, expectedResult);
 
@@ -425,7 +425,7 @@ private Q_SLOTS:
     void testCalendarSearch_data()
     {
         QTest::addColumn<QString>("query");
-        QTest::addColumn<QList<qint64> >("collections");
+        QTest::addColumn<QVector<qint64> >("collections");
         QTest::addColumn<QStringList>("mimeTypes");
         QTest::addColumn<QSet<qint64> >("expectedResult");
         const QStringList calendarMimeTypes = QStringList() << KCalCore::Event::eventMimeType();
@@ -433,7 +433,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::Organizer, "organizer@example.com", Akonadi::SearchTerm::CondEqual));
 
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result = QSet<qint64>() << 2001;
             QTest::newRow("find organizer") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
@@ -441,63 +441,63 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::Organizer, "organizer2@example.com", Akonadi::SearchTerm::CondEqual));
 
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result;
             QTest::newRow("find no organizer") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::PartStatus, "attendee1@example.com0", Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result = QSet<qint64>() << 2001;
             QTest::newRow("find events needsAction") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::PartStatus, "attendee2@example.com1", Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result = QSet<qint64>() << 2001;
             QTest::newRow("find events accepted") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::PartStatus, "attendee3@example.com2", Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result = QSet<qint64>() << 2001;
             QTest::newRow("find events declined") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::PartStatus, "attendee4@example.com3", Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result = QSet<qint64>() << 2001;
             QTest::newRow("find events tentative") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::PartStatus, "attendee5@example.com4", Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result = QSet<qint64>() << 2001;
             QTest::newRow("find events delegated") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::PartStatus, "attendee5@example.com5", Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result;
             QTest::newRow("unknown partstatus") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::Summary, "title", Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result = QSet<qint64>() << 2001;
             QTest::newRow("find event summary") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::IncidenceSearchTerm(Akonadi::IncidenceSearchTerm::Location, "here", Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 6;
+            QVector<qint64> collections = QVector<qint64>() << 6;
             QSet<qint64> result = QSet<qint64>() << 2001;
             QTest::newRow("find events location") << QString::fromLatin1(query.toJSON()) << collections << calendarMimeTypes << result;
         }
@@ -512,7 +512,7 @@ private Q_SLOTS:
     void testNoteSearch_data()
     {
         QTest::addColumn<QString>("query");
-        QTest::addColumn<QList<qint64> >("collections");
+        QTest::addColumn<QVector<qint64> >("collections");
         QTest::addColumn<QStringList>("mimeTypes");
         QTest::addColumn<QSet<qint64> >("expectedResult");
         const QStringList notesMimeTypes = QStringList() << QStringLiteral("text/x-vnd.akonadi.note");
@@ -520,7 +520,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Subject, QStringLiteral("note"), Akonadi::SearchTerm::CondEqual));
 
-            QList<qint64> collections = QList<qint64>() << 5;
+            QVector<qint64> collections = QVector<qint64>() << 5;
             QSet<qint64> result = QSet<qint64>() << 1000;
             QTest::newRow("find note subject equal") << QString::fromLatin1(query.toJSON()) << collections << notesMimeTypes << result;
         }
@@ -528,8 +528,8 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Subject, QStringLiteral("note1"), Akonadi::SearchTerm::CondEqual));
 
-            QList<qint64> collections = QList<qint64>() << 5;
-            QSet<qint64> result ;
+            QVector<qint64> collections = QVector<qint64>() << 5;
+            QSet<qint64> result;
             QTest::newRow("find note subject equal") << QString::fromLatin1(query.toJSON()) << collections << notesMimeTypes << result;
         }
         {
@@ -537,7 +537,7 @@ private Q_SLOTS:
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Subject, QStringLiteral("note"), Akonadi::SearchTerm::CondEqual));
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Body, QStringLiteral("note"), Akonadi::SearchTerm::CondEqual));
 
-            QList<qint64> collections = QList<qint64>() << 5;
+            QVector<qint64> collections = QVector<qint64>() << 5;
             QSet<qint64> result = QSet<qint64>() << 1000 << 1001;
             QTest::newRow("find note subject equal or body equal") << QString::fromLatin1(query.toJSON()) << collections << notesMimeTypes << result;
         }
@@ -546,7 +546,7 @@ private Q_SLOTS:
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Subject, QStringLiteral("note3"), Akonadi::SearchTerm::CondEqual));
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Body, QStringLiteral("note3"), Akonadi::SearchTerm::CondEqual));
 
-            QList<qint64> collections = QList<qint64>() << 5;
+            QVector<qint64> collections = QVector<qint64>() << 5;
             QSet<qint64> result = QSet<qint64>() << 1002;
             QTest::newRow("find note subject equal and body equal") << QString::fromLatin1(query.toJSON()) << collections << notesMimeTypes << result;
         }
@@ -555,7 +555,7 @@ private Q_SLOTS:
             Akonadi::EmailSearchTerm term(Akonadi::EmailSearchTerm::Subject, QStringLiteral("note3"), Akonadi::SearchTerm::CondEqual);
             term.setIsNegated(true);
             query.addTerm(term);
-            QList<qint64> collections = QList<qint64>() << 5;
+            QVector<qint64> collections = QVector<qint64>() << 5;
             QSet<qint64> result = QSet<qint64>() << 1000 << 1001;
             QTest::newRow("find not subject equal note3") << QString::fromLatin1(query.toJSON()) << collections << notesMimeTypes << result;
         }
@@ -573,7 +573,7 @@ private Q_SLOTS:
     void testContactSearch_data()
     {
         QTest::addColumn<QString>("query");
-        QTest::addColumn<QList<qint64> >("collections");
+        QTest::addColumn<QVector<qint64> >("collections");
         QTest::addColumn<QStringList>("mimeTypes");
         QTest::addColumn<QSet<qint64> >("expectedResult");
         const QStringList contactMimeTypes = QStringList() << KContacts::Addressee::mimeType();
@@ -583,7 +583,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("John"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections;
+            QVector<qint64> collections;
             QSet<qint64> result = QSet<qint64>() << 100;
             QTest::newRow("contact by name") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -591,7 +591,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("John"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections = QList<qint64>() << 4;
+            QVector<qint64> collections = QVector<qint64>() << 4;
             QSet<qint64> result;
             QTest::newRow("contact collectionfilter") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -599,7 +599,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("john"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections = QList<qint64>() << 3;
+            QVector<qint64> collections = QVector<qint64>() << 3;
             QSet<qint64> result = QSet<qint64>() << 100;
             QTest::newRow("contact by lowercase name") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -607,7 +607,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Nickname, QStringLiteral("JD"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections = QList<qint64>() << 3;
+            QVector<qint64> collections = QVector<qint64>() << 3;
             QSet<qint64> result = QSet<qint64>() << 100;
             QTest::newRow("contact by nickname") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -615,7 +615,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Uid, QStringLiteral("uid1"), Akonadi::SearchTerm::CondEqual));
 
-            QList<qint64> collections = QList<qint64>() << 3;
+            QVector<qint64> collections = QVector<qint64>() << 3;
             QSet<qint64> result = QSet<qint64>() << 100;
             QTest::newRow("contact by uid") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -623,7 +623,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Email, QStringLiteral("JANE@TEST.COM"), Akonadi::SearchTerm::CondEqual));
 
-            QList<qint64> collections = QList<qint64>() << 3;
+            QVector<qint64> collections = QVector<qint64>() << 3;
             QSet<qint64> result = QSet<qint64>() << 101 << 102;
             QTest::newRow("contact by email") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -631,7 +631,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("Doe"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections;
+            QVector<qint64> collections;
             QSet<qint64> result = QSet<qint64>() << 100 << 101 << 102;
             QTest::newRow("contact by name (Doe)") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -639,7 +639,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("Do"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections;
+            QVector<qint64> collections;
             QSet<qint64> result = QSet<qint64>() << 100 << 101 << 102;
             QTest::newRow("contact by name (Do)") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -648,7 +648,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("group1"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections;
+            QVector<qint64> collections;
             QSet<qint64> result = QSet<qint64>() << 103;
             QTest::newRow("contact group by name (group1)") << QString::fromLatin1(query.toJSON()) << collections << contactGroupMimeTypes << result;
         }
@@ -656,7 +656,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("group2"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections;
+            QVector<qint64> collections;
             QSet<qint64> result;
             QTest::newRow("contact group by name (group2)") << QString::fromLatin1(query.toJSON()) << collections << contactGroupMimeTypes << result;
         }
@@ -664,7 +664,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("group3"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections = QList<qint64>() << 4;
+            QVector<qint64> collections = QVector<qint64>() << 4;
             QSet<qint64> result = QSet<qint64>() << 104;
             QTest::newRow("contact group by name (group3 in collection 4)") << QString::fromLatin1(query.toJSON()) << collections << contactGroupMimeTypes << result;
         }
@@ -672,7 +672,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("group3"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections = QList<qint64>() << 3;
+            QVector<qint64> collections = QVector<qint64>() << 3;
             QSet<qint64> result;
             QTest::newRow("contact group by name (group3 in collection 3)") << QString::fromLatin1(query.toJSON()) << collections << contactGroupMimeTypes << result;
         }
@@ -682,7 +682,7 @@ private Q_SLOTS:
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::ContactSearchTerm(Akonadi::ContactSearchTerm::Name, QStringLiteral("oe"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections;
+            QVector<qint64> collections;
             QSet<qint64> result = QSet<qint64>() << 100 << 101 << 102;
             QTest::newRow("contact by name (oe)") << QString::fromLatin1(query.toJSON()) << collections << contactMimeTypes << result;
         }
@@ -692,16 +692,16 @@ private Q_SLOTS:
     void testEmailSearch_data()
     {
         QTest::addColumn<QString>("query");
-        QTest::addColumn<QList<qint64> >("collections");
+        QTest::addColumn<QVector<qint64> >("collections");
         QTest::addColumn<QStringList>("mimeTypes");
         QTest::addColumn<QSet<qint64> >("expectedResult");
         const QStringList emailMimeTypes = QStringList() << QStringLiteral("message/rfc822");
-        const QList<qint64> allEmailCollections = QList<qint64>() << 1 << 2;
+        const QVector<qint64> allEmailCollections = QVector<qint64>() << 1 << 2;
 #if 1
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Subject, QStringLiteral("subject1"), Akonadi::SearchTerm::CondEqual));
-            QList<qint64> collections = QList<qint64>() << 1;
+            QVector<qint64> collections = QVector<qint64>() << 1;
             QSet<qint64> result = QSet<qint64>() << 1;
             QTest::newRow("find subject equal") << QString::fromLatin1(query.toJSON()) << collections << emailMimeTypes << result;
         }
@@ -710,7 +710,7 @@ private Q_SLOTS:
             Akonadi::EmailSearchTerm term(Akonadi::EmailSearchTerm::Subject, QStringLiteral("subject1"), Akonadi::SearchTerm::CondEqual);
             term.setIsNegated(true);
             query.addTerm(term);
-            QList<qint64> collections = QList<qint64>() << 2;
+            QVector<qint64> collections = QVector<qint64>() << 2;
             QSet<qint64> result = QSet<qint64>() << 2 << 3 << 4 << 5 << 6;
             QTest::newRow("find subject equal negated") << QString::fromLatin1(query.toJSON()) << collections << emailMimeTypes << result;
         }
@@ -723,7 +723,7 @@ private Q_SLOTS:
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Body, QStringLiteral("body"), Akonadi::SearchTerm::CondContains));
-            QList<qint64> collections = QList<qint64>() << 1 << 2 << 3 << 4;
+            QVector<qint64> collections = QVector<qint64>() << 1 << 2 << 3 << 4;
             QSet<qint64> result = QSet<qint64>() << 1 << 2 << 3 << 4 << 6;
             QTest::newRow("find body contains") << QString::fromLatin1(query.toJSON()) << collections << emailMimeTypes << result;
         }
@@ -769,7 +769,7 @@ private Q_SLOTS:
         {
             Akonadi::SearchQuery query;
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::Subject, QStringLiteral("subject"), Akonadi::SearchTerm::CondContains));
-            QList<qint64> collections = QList<qint64>() << 1;
+            QVector<qint64> collections = QVector<qint64>() << 1;
             QSet<qint64> result = QSet<qint64>() << 1;
             QTest::newRow("filter by collection") << QString::fromLatin1(query.toJSON()) << collections << emailMimeTypes << result;
         }
@@ -944,7 +944,7 @@ private Q_SLOTS:
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::MessageStatus, QString::fromLatin1(Akonadi::MessageFlags::Deleted), Akonadi::SearchTerm::CondContains));
             query.addTerm(Akonadi::EmailSearchTerm(Akonadi::EmailSearchTerm::HeaderListId, QStringLiteral("kde-pim.kde.org"), Akonadi::SearchTerm::CondContains));
 
-            QList<qint64> collections;
+            QVector<qint64> collections;
             QSet<qint64> result = QSet<qint64>() << 4 << 5;
             QTest::newRow("find by message by deleted status or headerListId in all collections") << QString::fromLatin1(query.toJSON()) << collections << emailMimeTypes << result;
         }
@@ -1007,7 +1007,7 @@ private Q_SLOTS:
 
 };
 
-QTEST_MAIN(SearchPluginTest)
+QTEST_GUILESS_MAIN(SearchPluginTest)
 
 #include "searchplugintest.moc"
 
