@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2014 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -120,7 +120,7 @@ ResultIterator NoteQuery::exec()
     }
     try {
         Xapian::Query query(Xapian::Query::OP_OR, m_queries.begin(), m_queries.end());
-        qDebug() << query.get_description().c_str();
+        //qDebug() << query.get_description().c_str();
 
         Xapian::Enquire enquire(db);
         enquire.set_query(query);
